# MOBiceps
![MOBicpes logo](./images/MOBiceps.png)
MOBiceps is a collection of python functions for omics and mass spectrometry data. It is the working arm of [MOAgent](https://github.com/wollscheidlab/MOAgent). An early version of its core function featureSelector.py was first time applied in the work [Nature Communications, 2023](https://www.nature.com/articles/s41467-023-42101-z) to identify phenotype-specific proteins in myeloproliferative neoplasms (blood cancer).
If you have any questions please do not hesitate to contact jsettelmeier@ethz.ch

## Basic instructions

You can use MOBiceps by cloning the repo to your local machine using

```bash
$ git clone https://github.com/wollscheidlab/MOBiceps.git
```
or using the python package distribution system pip via

```bash
$ pip install MOBiceps
```
